@@ -10,7 +10,7 @@ from spacy.vocab import Vocab
 from wasabi import msg
 
 
-def set_lexeme_prob_table(vocab: Vocab, verbose: bool = True):
+def set_lexeme_prob_table(vocab: Vocab, verbose: bool = False):
     """Ensure that the pipeline has a lexeme probability table."""
     if not vocab.lookups.has_table("lexeme_prob"):
         if verbose:
@@ -32,7 +32,7 @@ def perplexity(entropy: float) -> float:
     """Calculates the perplexity.
 
     Calculated as exp(H(p)), where H is the entropy using a base e and p is the
-    probabilites of a given word.
+    probabilities of a given word.
     """
     return np.exp(entropy)
 
@@ -47,7 +47,7 @@ def perplexity_getter(doc: Union[Doc, Span]) -> float:
     """Calculates the perplexity of a doc.
 
     Calculated as exp(H(p)), where H is the entropy using a base e and p is the
-    probabilites of a given word.
+    probabilities of a given word.
     """
     # check if it has the attribute entropy
     if hasattr(doc._, "entropy") and doc._.entropy is not None:
@@ -88,7 +88,7 @@ class InformationTheory:
     def __init__(self, nlp: Language, name: str, force: bool) -> None:
         self.name = name
         self.set_extensions(force=force)
-        set_lexeme_prob_table(nlp.vocab)
+        set_lexeme_prob_table(nlp.vocab, verbose=False)
 
     @staticmethod
     def dict_getter(doc: Union[Doc, Span]) -> Dict[str, float]:
